"""Financial tools package.

Tools in this package are dynamically discovered and registered via ToolRegistry.
"""

# No explicit imports or __all__ needed here anymore.
# The ToolRegistry will handle discovery.
