import pandas as pd
from yfinance import utils as utils
from yfinance.const import quote_summary_valid_modules as quote_summary_valid_modules
from yfinance.data import YfData as YfData
from yfinance.exceptions import YFException as YFException

class Analysis:
    def __init__(self, data: YfData, symbol: str, proxy=...) -> None: ...
    @property
    def earnings_estimate(self) -> pd.DataFrame: ...
    @property
    def revenue_estimate(self) -> pd.DataFrame: ...
    @property
    def eps_trend(self) -> pd.DataFrame: ...
    @property
    def eps_revisions(self) -> pd.DataFrame: ...
    @property
    def analyst_price_targets(self) -> dict: ...
    @property
    def earnings_history(self) -> pd.DataFrame: ...
    @property
    def growth_estimates(self) -> pd.DataFrame: ...
