import pandas as pd
from yfinance import utils as utils
from yfinance.data import YfData as YfData
from yfinance.exceptions import YFDataException as YFDataException

class Holders:
    def __init__(self, data: YfData, symbol: str, proxy=...) -> None: ...
    @property
    def major(self) -> pd.DataFrame: ...
    @property
    def institutional(self) -> pd.DataFrame: ...
    @property
    def mutualfund(self) -> pd.DataFrame: ...
    @property
    def insider_transactions(self) -> pd.DataFrame: ...
    @property
    def insider_purchases(self) -> pd.DataFrame: ...
    @property
    def insider_roster(self) -> pd.DataFrame: ...
