import pandas as pd
from _typeshed import Incomplete

from . import utils as utils
from .data import YfData as YfData
from .exceptions import YFException as YFException

LOOKUP_TYPES: Incomplete

class Lookup:
    session: Incomplete
    query: Incomplete
    timeout: Incomplete
    raise_errors: Incomplete
    def __init__(
        self, query: str, session: Incomplete | None = None, proxy=..., timeout: int = 30, raise_errors: bool = True
    ) -> None: ...
    def get_all(self, count: int = 25) -> pd.DataFrame: ...
    def get_stock(self, count: int = 25) -> pd.DataFrame: ...
    def get_mutualfund(self, count: int = 25) -> pd.DataFrame: ...
    def get_etf(self, count: int = 25) -> pd.DataFrame: ...
    def get_index(self, count: int = 25) -> pd.DataFrame: ...
    def get_future(self, count: int = 25) -> pd.DataFrame: ...
    def get_currency(self, count: int = 25) -> pd.DataFrame: ...
    def get_cryptocurrency(self, count: int = 25) -> pd.DataFrame: ...
    @property
    def all(self) -> pd.DataFrame: ...
    @property
    def stock(self) -> pd.DataFrame: ...
    @property
    def mutualfund(self) -> pd.DataFrame: ...
    @property
    def etf(self) -> pd.DataFrame: ...
    @property
    def index(self) -> pd.DataFrame: ...
    @property
    def future(self) -> pd.DataFrame: ...
    @property
    def currency(self) -> pd.DataFrame: ...
    @property
    def cryptocurrency(self) -> pd.DataFrame: ...
